@@ -13,8 +13,9 @@ from petisco.application.singleton import Singleton
 from petisco.domain.aggregate_roots.aggregate_root import AggregateRoot
 from petisco.domain.aggregate_roots.info_id import InfoId
 from petisco.domain.errors.empty_value_object_error import EmptyValueObjectError
-from petisco.domain.errors.exceed_length_limit_value_error_error import (
+from petisco.domain.errors.length_limit_string_value_object_error import (
     ExceedLengthLimitValueObjectError,
+    NotReachMinimumValueObjectError,
 )
 from petisco.domain.errors.given_name_is_not_valid_error import GivenNameIsNotValidError
 from petisco.domain.errors.unknown_error import UnknownError
@@ -43,6 +44,15 @@ from petisco.events.subscriber.infrastructure.not_implemented_event_subscriber i
     NotImplementedEventSubscriber,
 )
 from petisco.frameworks.interface_application import IApplication
+from petisco.http.request import Request
+from petisco.http.request_errors import (
+    MultipartFormatRequestError,
+    MissingSchemaRequestError,
+    TimeoutRequestError,
+    ConnectionRequestError,
+    UnknownRequestError,
+)
+from petisco.http.response import Response
 from petisco.logger.log_message import LogMessage
 from petisco.logger.logging_based_logger import LoggingBasedLogger
 from petisco.logger.interface_logger import ILogger
@@ -107,6 +117,7 @@ classes = [
     "Config",
     "EmptyValueObjectError",
     "ExceedLengthLimitValueObjectError",
+    "NotReachMinimumValueObjectError",
     "subscriber_handler",
     "ConfigEventSubscriber",
     "IEventPublisher",
@@ -117,6 +128,13 @@ classes = [
     "NotImplementedNotifier",
     "NotifierMessage",
     "LogMessage",
+    "Request",
+    "Response",
+    "MultipartFormatRequestError",
+    "MissingSchemaRequestError",
+    "TimeoutRequestError",
+    "ConnectionRequestError",
+    "UnknownRequestError",
 ]
 
 # Controllers & Use Cases
@@ -142,7 +160,6 @@ controllers_and_use_cases = [
     "PersistenceError",
 ]
 
-
 # Constants
 from petisco.logger.interface_logger import (
     CRITICAL,
@@ -210,7 +227,6 @@ try:
 except (RuntimeError, ImportError):
     rabbitmq = []
 
-
 # Slack
 try:
     from petisco.notifier.infrastructure.slack.slack_notifier import SlackNotifier
